<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Conditional
 * @copyright   Copyright (c) 2022, WeCodeArt Framework
 * @since 		4.0
 * @version		5.2.2
 */

namespace WeCodeArt;

defined( 'ABSPATH' ) || exit();

use ArrayAccess;

/**
 * Conditional.
 *
 * @author     Bican Marian Valeriu <marianvaleriubican@gmail.com>
 */
class Conditional implements ArrayAccess {

    use Singleton;

    /**
     * All of the conditional items.
     *
     * @var array
     */
    protected $items = [];

    /**
     * Create a new conditional repository.
     *
     * @param  array  $items
     *
     * @return void
     */
    public function init() {
        foreach( apply_filters( 'wecodeart/filter/conditionals', [
			'is_theme_admin'    => Conditional\Settings::class,
			'is_front_page'     => Conditional\Front::class,
            'is_dev_mode'       => Conditional\Debug::class,
		] ) as $key => $condition ) {
            $this->register( $key, $condition );
        }
    }
	
    /**
     * Determine if the given conditional value exists.
     *
     * @param  string  $key
     *
     * @return bool
     */
    public function has( $key ) {
        return isset( $this->items[$key] );
    }

    /**
     * Get the specified conditional value.
     *
     * @param  string  $key
     * @param  mixed   $default
     *
     * @return mixed
     */
    public function get( $key, $default = null ) {
        if ( ! isset( $this->items[$key] ) ) {
            return $default;
        }

        return apply_filters( "wecodeart/conditional/get/{$key}", $this->items[$key] );
    }

    /**
     * Set a given conditional value.
     *
     * @param  array|string  $key
     * @param  mixed   $value
     *
     * @return void
     */
    public function set( $key, $value = null ) {
        $keys = is_array( $key ) ? $key : [ $key => $value ];

        foreach ( $keys as $key => $value ) {
            $this->items[$key] = apply_filters( "wecodeart/conditional/set/{$key}", $value );
        }
    }
    
    /**
     * Set a given conditional value.
     *
     * @param  array|string  $key
     * @param  mixed   $value
     *
     * @return void
     */
    public function register( $key, $value = null ) {
        return $this->set( $key, $value );
    }

    /**
     * Get all of the conditional items for the application.
     *
     * @return array
     */
    public function all() {
        return $this->items;
    }

    /**
     * Determine if the given conditional option exists.
     *
     * @param  string  $key
     *
     * @return bool
     */
    public function offsetExists( $key ) {
        return $this->has( $key );
    }

    /**
     * Get a conditional option.
     *
     * @param  string  $key
     *
     * @return mixed
     */
    public function offsetGet( $key ) {
        return $this->get( $key );
    }

    /**
     * Set a conditional option.
     *
     * @param  string  $key
     * @param  mixed  $value
     *
     * @return void
     */
    public function offsetSet( $key, $value ) {
        $this->set( $key, $value );
    }

    /**
     * Unset a conditional option.
     *
     * @param  string  $key
     *
     * @return void
     */
    public function offsetUnset( $key ) {
        $this->set( $key, null );
    }
}