<?php
/**
 * WeCodeArt Framework
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package		WeCodeArt Framework
 * @subpackage  Gutenberg\Blocks
 * @copyright   Copyright (c) 2022, WeCodeArt Framework
 * @since		5.2.4
 * @version		5.3.1
 */

namespace WeCodeArt\Gutenberg\Blocks\Design;

defined( 'ABSPATH' ) || exit();

use WeCodeArt\Singleton;
use WeCodeArt\Gutenberg\Blocks\Dynamic;
use function WeCodeArt\Functions\get_prop;

/**
 * Gutenberg Columns blocks.
 */
class Columns extends Dynamic {

	use Singleton;

	/**
	 * Block namespace.
	 *
	 * @var string
	 */
	protected $namespace = 'core';

	/**
	 * Block name.
	 *
	 * @var string
	 */
	protected $block_name = 'columns';

	/**
	 * Shortcircuit Register
	 */
	public function register() {
		// add_filter( 'register_block_type_args',	[ $this, 'register_args' ], 10, 2 );
	}

	/**
	 * Filter register args
	 *
	 * @param	array 	$settings
	 * @param	array 	$data
	 */
	public function register_args( $args, $name ) {
		if ( $this->get_block_type() === $name ) {
			if ( isset( $args['supports']['spacing'] ) ) {
				$existing 	= (array) $args['supports']['spacing'];
		
				$args['supports']['spacing'] = wp_parse_args( [
					'blockGap' => true
				], $existing );
			}
		}
		
		return $args;
	}

	/**
	 * Block styles
	 *
	 * @return 	string 	The block styles.
	 */
	public function styles() {
		$mobile	= wecodeart_json( [ 'settings', 'custom', 'breakpoints', 'sm' ], '640px' );

		return "
		.wp-block-columns {
			display: flex;
			flex-wrap: wrap;
			gap: var(--wp--style--block-gap);
		}
		.wp-block-columns.are-vertically-aligned-top {
			align-items: flex-start;
		}
		.wp-block-columns.are-vertically-aligned-center {
			align-items: center;
		}
		.wp-block-columns.are-vertically-aligned-bottom {
			align-items: flex-end;
		}
		.wp-block-column {
			max-width: 100%;
		}
		.wp-block-column.is-vertically-aligned-top {
			align-self: flex-start;
		}
		.wp-block-column.is-vertically-aligned-center {
			align-self: center;
		}
		.wp-block-column.is-vertically-aligned-bottom {
			align-self: flex-end;
		}
		@media (max-width: $mobile) {
			.wp-block-columns:not(.is-not-stacked-on-mobile) {
				flex-direction: column;
			}
		}
		";
	}
}
