<?php
/**
 * WeCodeArt Framework
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package		WeCodeArt Framework
 * @subpackage  Gutenberg\Blocks
 * @copyright   Copyright (c) 2022, WeCodeArt Framework
 * @since		5.0.0
 * @version		5.3.1
 */

namespace WeCodeArt\Gutenberg\Blocks\Media;

defined( 'ABSPATH' ) || exit();

use WeCodeArt\Singleton;
use WeCodeArt\Gutenberg\Blocks\Dynamic;
use function WeCodeArt\Functions\get_prop;

/**
 * Gutenberg Gallery block.
 */
class Gallery extends Dynamic {

	use Singleton;

	/**
	 * Block namespace.
	 *
	 * @var string
	 */
	protected $namespace = 'core';

	/**
	 * Block name.
	 *
	 * @var string
	 */
	protected $block_name = 'gallery';

	/**
	 * Shortcircuit Register
	 */
	public function register() {
		add_filter( 'render_block_core/' . $this->block_name, [ $this, 'render' ], 10, 2 );
	}

	/**
	 * Dynamically renders the `core/gallery` block.
	 *
	 * @param 	string 	$content 	The block markup.
	 * @param 	array 	$block 		The parsed block.
	 *
	 * @return 	string 	The block markup.
	 */
	public function render( $content = '', $block = [], $data = null ) {
		$attributes = get_prop( $block, 'attrs', [] );

		// Replace grid class
		$search 	= '/' . preg_quote( 'class="blocks-gallery-grid', '/' ) . '/';
		$replace 	= 'class="blocks-gallery-grid row row-cols-2 row-cols-md-' . get_prop( $attributes, 'columns', '2' );
		$content 	= preg_replace( $search, $replace, $content, 1 );
		
		// Replace nested images
		$search 	= '/' . preg_quote( 'has-nested-images', '/' ) . '/';
		$replace 	= 'has-nested-images row row-cols-2 row-cols-md-' . get_prop( $attributes, 'columns', '2' );
		$content 	= preg_replace( $search, $replace, $content, 1 );

		$content 	= preg_replace( '/( columns-)\w+/', '', $content, 1 );

		return $content;
	}

	/**
	 * Block styles
	 *
	 * @return 	string 	The block styles.
	 */
	public function styles() {
		return "
		.wp-block-gallery {
			margin-bottom: 0;
		}
		.wp-block-gallery.has-nested-images {
			max-width: initial;
		}
		.wp-block-gallery.alignleft,
		.wp-block-gallery.alignright {
			width: 100%;
		}
		.wp-block-gallery.aligncenter .blocks-gallery-item figure {
			justify-content: center;
		}
		.wp-block-gallery .blocks-gallery-grid {
			margin-bottom: 0;
			padding-left: 0;
			list-style: none;
		}
		.wp-block-gallery .blocks-gallery-image,
		.wp-block-gallery .blocks-gallery-item {
			display: flex;
			flex-grow: 1;
			flex-direction: column;
			justify-content: center;
		}
		.wp-block-gallery .blocks-gallery-image figure,
		.wp-block-gallery .blocks-gallery-item figure {
			position: relative;
			height: 100%;
		}
		.wp-block-gallery .blocks-gallery-image img,
		.wp-block-gallery .blocks-gallery-item img {
			display: block;
			max-width: 100%;
			width: 100%;
			height: auto;
		}
		.wp-block-gallery .blocks-gallery-image figcaption,
		.wp-block-gallery .blocks-gallery-item figcaption {
			position: absolute;
			bottom: 0;
			width: 100%;
			max-height: 100%;
			overflow: auto;
			padding: 40px 10px 10px;
			color: #fff;
			text-align: center;
			background: linear-gradient(0deg, rgba(0, 0, 0, 0.7) 0, rgba(0, 0, 0, 0.3) 70%, transparent);
		}
		.wp-block-gallery .blocks-gallery-image figcaption img,
		.wp-block-gallery .blocks-gallery-item figcaption img {
			display: inline;
		}
		.wp-block-gallery.is-cropped .wp-block-image a,
		.wp-block-gallery.is-cropped .wp-block-image img,
		.wp-block-gallery.is-cropped .blocks-gallery-image a,
		.wp-block-gallery.is-cropped .blocks-gallery-image img,
		.wp-block-gallery.is-cropped .blocks-gallery-item a,
		.wp-block-gallery.is-cropped .blocks-gallery-item img {
			width: 100%;
		}
		@supports (position: sticky) {
			.wp-block-gallery .blocks-gallery-image figure,
			.wp-block-gallery .blocks-gallery-item figure {
				display: flex;
				align-items: flex-end;
				justify-content: flex-start;
			}
			.wp-block-gallery .blocks-gallery-image img,
			.wp-block-gallery .blocks-gallery-item img {
				width: auto;
			}
			.wp-block-gallery.is-cropped .wp-block-image a,
			.wp-block-gallery.is-cropped .wp-block-image img,
			.wp-block-gallery.is-cropped .blocks-gallery-image a,
			.wp-block-gallery.is-cropped .blocks-gallery-image img,
			.wp-block-gallery.is-cropped .blocks-gallery-item a,
			.wp-block-gallery.is-cropped .blocks-gallery-item img {
				height: 100%;
				flex: 1;
				object-fit: cover;
			}
		}
		";
	}
}
